@@ -1,8 +1,7 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
 import logging
-from . import BaseCodec
+from converter.codecs import BaseCodec
 
 logger = logging.getLogger(__name__)
 
