@@ -1,6 +1,5 @@
-#!/usr/bin/env python
+# -*- coding: utf-8 -*-
 
-import os.path
 import os
 import re
 import signal
